<?php
/*
Plugin Name: Easy Expand
Text Domain: easy-expand
Description: Easy Expand adds an [exp] shortcode that wraps content into a lovely, jQuery collapsible div.
Version: 1.0
Author: PixelSmith
License: GPL2
Requires at least: 4.9  
Requires PHP: 7.2 
*/

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Class PSPEE_Easy_Expand
 * @package PSPEE_Easy_Expand
 * @category WordPress Plugins
 */


class PSPEE_Easy_Expand {

	/**
	 * Current version
	 * @var string
	 */
	public $version = '1.0';

	/**
	 * Used as prefix for options entry
	 * @var string
	 */
	public $domain = 'pspee';

	/**
	 * Name of the options
	 * @var string
	 */
	public $settings_name = 'PSPEE_Easy_Expand_settings';

	/**
	 * @var array
	 */
	public $settings = array(
		'style' => 'light',
		'cid' => '',
		'tag' => 'span',
		'trigclass' => '',
		'targtag' => 'div',
		'targclass' => '',
		'notitle' => '',
		'duration' => 'fast',
		'tabindex' => '0',
		'slideEffect' => 'slideFade',
		'custom_css' => '',
		'script_check' => '',
		'css_check' => '',
		'script_location' => 'footer',
		'cc_download_key' => '',
		'cc_email' => '',
		'filter_content' => '',
		'pauseinit' => '',
		'cc_display_id' => '',
		'cc_display_title' => '',
		'touch_start' => '',
	);
	

	/**
	 * PHP constructor
	 */
	function __construct() {
		// set option values
		$this->_set_settings();

		//load the script and style if viewing the front-end
		add_action('wp_enqueue_scripts', array( $this, 'collapsTronicInit' ) );
		add_action('admin_enqueue_scripts', array( $this, 'codemirror_enqueue_scripts') );

		// add actions
		add_action( 'admin_menu', array( $this, 'admin_menu' ) );
		add_action( 'plugin_action_links_' . plugin_basename(__FILE__), array( $this, 'plugin_actions' ) );
		add_action( 'admin_init', array( $this, 'admin_init' ) );
		add_shortcode('pspee_exp', array($this, 'shortcode'));
		add_shortcode('pspee', array($this, 'shortcode'));

		//add expsub shortcodes
		for ($i=1; $i<30; $i++) {
			add_shortcode('pspee_expsub'.$i, array($this, 'shortcode'));
		}

		// Add shortcode support for widgets
		add_filter('widget_text', 'do_shortcode');
	}

	/**
	 * Callback init
	 */
	function collapsTronicInit() {
		//expand script
		$load_in_footer = false;
		if($this->settings['script_location'] == 'footer' ){
			$load_in_footer = true;
		}
		wp_register_script('easy-expand-js', plugins_url('js/expandable.js', __FILE__), array('jquery'), '1.7.2', $load_in_footer);
		
		//prep settings for injection
		$pspee_settings = [
			'pspeeduration' => $this->settings['duration'],
			'pspeeslideEffect' => $this->settings['slideEffect'],
			'pspeepauseInit' => $this->settings['pauseinit'],
			'pspeetouchstart' => $this->settings['touch_start']
		];
		wp_add_inline_script( 'easy-expand-js', 'const pspee_settings = ' . wp_json_encode( $pspee_settings ), 'before' );

		if( empty($this->settings['script_check']) ){
			wp_enqueue_script('easy-expand-js');
		}

		//css
		wp_register_style( 'easy-expand-main-css', plugins_url('css/core_style.css', __FILE__) , array (), '1.0' );
		wp_register_style( 'easy-expand-css', plugins_url('css/'.$this->settings['style'].'_style.css', __FILE__) , array (), '1.6' );
		if( !empty( $this->settings['custom_css'] ) ){
			wp_add_inline_style( 'easy-expand-custom-css', esc_html($this->settings['custom_css']) );
		}

		if( empty($this->settings['css_check'])){
			wp_enqueue_style( 'easy-expand-custom-css' );
			if ($this->settings['style'] !== 'none') {
				wp_enqueue_style( 'easy-expand-css' );
			}
		}
	}

	function codemirror_enqueue_scripts($hook) {
		if($hook == 'settings_page_easy-expand-settings'){
			wp_register_script('cm_js', plugins_url('js/extend_cm.js', __FILE__), array('jquery'), '0.1.0', true);
			$cm_settings = wp_enqueue_code_editor(
				[
					'type' => 'text/css',
					'codemirror' => [
						'lineNumbers' => true,
						'autoRefresh' => true
					]
				]
			);
			wp_localize_script('cm_js', 'cm_settings', $cm_settings);
			wp_enqueue_script( 'cm_js' );
			wp_enqueue_script( 'wp-theme-plugin-editor' );
			wp_enqueue_style( 'wp-codemirror' );
		}
	}

	/**
	 * Callback admin_menu
	 */
	function admin_menu() {
		if ( function_exists( 'add_options_page' ) AND current_user_can( 'manage_options' ) ) {
			// add options page
			$page = add_options_page('Easy Expand Settings', 'Easy Expand', 'manage_options', 'easy-expand-settings', array( $this, 'settings_page' ));
		}
	}

	/**
	 * Callback admin_init
	 */
	function admin_init() {
		// register settings
		register_setting( 
		  $this->domain, 
		  $this->settings_name,
		  array(
            'type' => 'string',
            'sanitize_callback' => 'pspee_sanitize_text_or_array_field',
           )
    );
	}

	/**
	 * Callback shortcode
	 */
	function shortcode($atts, $content = null){
		$options = $this->settings;
		if( !empty($this->settings['script_check']) ){
			wp_enqueue_script('easy-expand-js');
		}

		if( !empty($this->settings['css_check'])){
			wp_enqueue_style( 'easy-expand-custom-css' );
			if ($this->settings['style'] !== 'none') {
				wp_enqueue_style( 'easy-expand-css' );
			}
		}

		//find a random number, if no id is assigned
		$ran = uniqid();
		$atts_array = shortcode_atts(array(
				'title' => '',
				'cid' => intval($options['cid']),
				'template_id' => '',
				'swaptitle' => '',
				'alt' => '',
				'swapalt' => '',
				'notitle' => $options['notitle'],
				'id' => 'id'.$ran,
				'tag' => $options['tag'],
				'trigclass' => $options['trigclass'],
				'targtag' => $options['targtag'],
				'targclass' => $options['targclass'],
				'targpos' => '',
				'trigpos' => 'above',
				'rel' => '',
				'group' => '',
				'togglegroup' => '',
				'expanded' => '',
				'excerpt' => '',
				'swapexcerpt' => false,
				'excerptpos' => 'below-trigger',
				'excerpttag' => 'div',
				'excerptclass' => '',
				'findme' => '',
				'scrollonclose' => '',
				'startwrap' => '',
				'endwrap' => '',
				'elwraptag' => '',
				'elwrapclass' => '',
				'filter' => $options['filter_content'],
				'tabindex' => $options['tabindex'],
				'animation_effect' => '',
				'duration' => '',
				'orderby' => '',
				'order' => ''
			), $atts, 'pspee_exp');
			
		foreach($atts_array as $var => $val) {
		   ${$var} = $val;
		}


		if(!empty($triggertext)){
			$title = $triggertext;
		}
		if(!empty($highlander) && !empty($rel)){
			$rel .= '-highlander';
		}

		//content filtering
		if(empty($filter) || $filter == 'false'){
			$content = do_shortcode($content);
		}
		else{
			$content = apply_filters( 'the_content', $content );
			$content = str_replace( ']]>', ']]>', $content );
		}

		if( !empty($cid) && $cid = intval($cid) && get_edit_post_link($cid) ){
			$content .= '<div class="com_edit_link"><a class="post-edit-link" href="'.get_edit_post_link($cid).'">'.__('Edit', 'easy-expand').'</a></div>';
		}

		if( !empty($sub_cids) ){
			foreach($sub_cids as $sub_cid){
				$args = array('cid' => $sub_cid);
				$content .= $this->shortcode($args);
			}
		}

		$ewo = '';
		$ewc = '';
		
		$id = preg_replace('/\s+/', '_', esc_attr($id));

		//placeholders
		$placeholder_arr = array('%(%', '%)%', '%{%', '%}%');
		$swapout_arr = array('<', '>', '[', ']');

		//allowed tags
		$allowed_tags = [
			"div", "span", "p", "li", "ul", "ol", "strong", "b",
			"em", "i", "u", "h1", "h2", "h3", "h4", "h5", "h6",
			"blockquote", "a", "img", "button", "tr", "td", "th", "caption", "small", "cite", "q", $options['tag']
		];
		
		if(!empty($tag)){
			$tag = $this->filter_allowed_tags( $tag, $allowed_tags );
		}

		$title = do_shortcode(str_replace($placeholder_arr, $swapout_arr, $title));
		if($swaptitle){
			$swaptitle = do_shortcode(str_replace($placeholder_arr, $swapout_arr, $swaptitle));
		}
		if($startwrap){
			$startwrap = do_shortcode(str_replace($placeholder_arr, $swapout_arr, $startwrap));
		}
		if($endwrap){
			$endwrap = do_shortcode(str_replace($placeholder_arr, $swapout_arr, $endwrap));
		}
		//need to check for a few versions, because of new option setting. can be removed after a few revisiosn.
		if(!empty($targtag)){
			$targtag = $this->filter_allowed_tags( $targtag, $allowed_tags );
		}
		else{
			$targtag = 'div';
		}

		
		if(!empty($elwraptag)){
			$ewclass = '';
			if($elwrapclass){
				$ewclass = 'class="'.esc_attr($elwrapclass).'"';
			}
			$elwraptag = $this->filter_allowed_tags( $elwraptag, $allowed_tags );

			$ewo = '<'. $elwraptag .' '.$ewclass.'>';
			$ewc = '</'. $elwraptag .'>';
		}

		$eDiv = '';

		if($content){
			$inline_class = '';
			$collapse_class = 'easyexpand_content ';
			if($targpos == 'inline'){
				$inline_class = 'pspee-inline ';
				$collapse_class = 'easyexpand_content_inline ';
			}
			$eDiv = '<'. esc_attr(  $targtag ) .' id="target-'.$id.'" class="'.esc_attr($collapse_class.$inline_class.$targclass).'">'. $content .'</'. esc_attr(  $targtag ) .'>';
		}
		if($excerpt){
			$excerpt = str_replace($placeholder_arr, $swapout_arr, $excerpt);
			$excerpt = do_shortcode($excerpt);
			$excerpt = apply_filters( 'pspee_excerpt', $excerpt );

			if($targpos == 'inline'){
				$excerpt .= $eDiv;
				$eDiv = '';
			}
			if($excerptpos == 'above-trigger'){
				$nibble = '<'. esc_attr( $excerpttag ) .' id="excerpt-'.esc_attr($id).'" class="'.esc_attr($excerptclass).'">'. esc_attr( $excerpt ).'</'. esc_attr( $excerpttag ) .'>';
			}
			else{
				$nibble = '<'. esc_attr( $excerpttag ) .' id="excerpt-'.esc_attr($id).'" class="easyexpand_excerpt '.esc_attr($excerptclass).'">'. esc_attr( $excerpt ) .'</'. esc_attr( $excerpttag ) .'>';
			}
			//swapexcerpt
			if($swapexcerpt !== false){
				$swapexcerpt = str_replace($placeholder_arr, $swapout_arr, $swapexcerpt);
				$swapexcerpt = do_shortcode($swapexcerpt);
				$swapexcerpt = apply_filters( 'pspee_swapexcerpt', $swapexcerpt );
				$nibble .= '<'. esc_attr( $excerpttag ) .' id="swapexcerpt-'.esc_attr($id).'" style="display:none;">'. esc_attr( $swapexcerpt ).'</'. esc_attr( $excerpttag ) .'>';
			}
		}
		$altatt = '';
		if(!empty($alt)){
			$altatt = 'alt="'.esc_attr($alt).'" title="'.esc_attr($alt).'"';
		}
		else if( empty($notitle) ){
			$altatt = 'title="'.esc_attr($title).'"';
		}
		$relatt = '';
		if(!empty($rel)){
			$relatt = 'rel="'.esc_attr($rel).'"';
		}

		$groupatt = '';
		//legacy
		if($group && !$togglegroup){
			$togglegroup = $group;
		}

		if($togglegroup){
			$groupatt = 'data-togglegroup="'.esc_attr($togglegroup).'"';
		}
		$inexatt = '';
		//var_dump($tabindex);
		if(!empty($tabindex) || $tabindex == 0 ){
			$inexatt = 'tabindex="'.esc_attr($tabindex).'"';
		}
		if($expanded && $expanded != 'false'){
			$trigclass .= ' pspee-close';
		}
		$anchor = '';
		if($findme){
			$trigclass .= ' find-me';
			$offset = '';
			if($findme != 'true' && $findme != 'auto'){
				$offset = $findme;
			}
			//$anchor = '<input type="hidden" id="find-'.$id.'" name="'.$offset.'"/>';
			$anchor = 'data-findme="'.$offset.'"';
		}

		//effect
		$effatt = '';
		if($animation_effect){
			$effatt = 'data-animation_effect="'.esc_attr($animation_effect).'"';
		}

		//duration
		$duratt = '';
		if($duration){
			$duratt = 'data-duration="'.esc_attr($duration).'"';
		}

		$closeanchor = '';
		if($scrollonclose && (is_numeric($scrollonclose) || $scrollonclose == 0)){
			$trigclass .= ' scroll-to-trigger';
			$closeanchor = '<input type="hidden" id="scrollonclose-'.esc_attr($id).'" name="'.esc_attr($scrollonclose).'"/>';
		}

		//deal with image from collapse-commander
		if( !empty($trigtype) && $trigtype == 'image' && !empty($triggerimage) && strtolower($tag) == 'img' ){
			$imageclass = 'easyexpand noarrow' . esc_attr($trigclass);
			$image_atts = array( 'id' => $id, 'class' => $imageclass, 'alt' => $alt );
			if(!$notitle){
				$image_atts['title'] = $alt;
			}
			$link = $closeanchor.wp_get_attachment_image( $triggerimage, 'full', false, $image_atts );
		}
		else{
			if(!empty($trigtype) && $trigtype == 'image' && !empty($triggerimage)){
				$title =  wp_get_attachment_image( $triggerimage, 'full' );
			}
			$link = $closeanchor.'<'. esc_attr($tag) .' class="easyexpand '.esc_attr($trigclass).'" id="'.esc_attr($id).'" '.$relatt.' '.$inexatt.' '.$altatt.' '.$anchor.' '.$groupatt.' '.$effatt.' '.$duratt.'>'.wp_kses_post($startwrap.$title.$endwrap).'</'. esc_attr($tag) .'>';
		}

		//swap image
		if( !empty($trigtype) && $trigtype == 'image' && !empty($swapimage) && strtolower($tag) == 'img' ){
			$link .= wp_get_attachment_image( $swapimage, 'full', false, array( 'id' => 'swap-'.$id, 'class' => 'pspee-swap', 'alt' => $swapalt, 'style' => 'display:none;' ) );
		}
		else{
			if(!empty($trigtype) && $trigtype == 'image' && !empty($swapimage)){
				$swaptitle = wp_get_attachment_image( $swapimage, 'full' );
			}
		}
		//swap title
		if($swaptitle){
			$swapalt_attr = '';
			if(!empty($swapalt)){
				$swapalt_attr = "alt='".esc_attr($swapalt)."'";
			}
			$link .= "<". esc_attr($tag) ." id='swap-".esc_attr($id)."' ".esc_attr($swapalt_attr)." class='pspee-swap' style='display:none;'>".wp_kses_post($startwrap.$swaptitle.$endwrap)."</". esc_attr($tag) .">";
		}

		if($excerpt){
			if($excerptpos == 'above-trigger'){
				if($trigpos == 'below'){
					$retStr = $ewo.$eDiv.$nibble.$link.$ewc;
				}
				else{
					$retStr = $ewo.$nibble.$link.$eDiv.$ewc;
				}
			}
			else if($excerptpos == 'below-trigger'){
				if($trigpos == 'below'){
					$retStr =  $ewo.$eDiv.$link.$nibble.$ewc;
				}
				else{
					$retStr = $ewo.$link.$nibble.$eDiv.$ewc;
				}
			}
			else{
				if($trigpos == 'below'){
					$retStr = $ewo.$eDiv.$link.$nibble.$ewc;
				}
				else{
					$retStr = $ewo.$link.$eDiv.$nibble.$ewc;
				}
			}
		}
		else{
			if($trigpos == 'below'){
				$retStr = $ewo.$eDiv.$link.$ewc;
			}
			else{
				$retStr = $ewo.$link.$eDiv.$ewc;
			}
		}
		return $retStr;
	}

	// Add link to options page from plugin list
	function plugin_actions($links) {
		$new_links = array();
		$new_links[] = '<a href="options-general.php?page=easy-expand-settings">' . __('Settings', 'easy-expand') . '</a>';
		return array_merge($new_links, $links);
	}

	/**
	 * Admin settings page
	 */
	function settings_page() {
	?>
		<div class="wrap">
			<h2>Easy Expand</h2>
		</div>

		<div class="postbox-container metabox-holder meta-box-sortables" style="width: 69%">
			<div style="margin:0 5px;">
				<div class="postbox">
					<h2 class="hndle"><span class="dashicons dashicons-admin-settings"></span> <?php esc_attr_e( 'Default Easy Expand Settings', 'easy-expand' ) ?></h2>
					<div class="inside">
						<form method="post" action="options.php">
							<?php
								settings_fields( $this->domain );
								$options = $this->settings;
							?>
							<fieldset class="options">
								<table class="form-table">
								<tr>
									<th><?php esc_attr_e( 'Style', 'easy-expand' ) ?>:</th>
									<td><label><select id="style" name="<?php echo esc_attr($this->settings_name); ?>[style]">
										<?php
											if(empty($options['style'])){
												$options['style'] = 'light';
											}
											$st_array = array(
												__('Light', 'easy-expand') => 'light',
												__('Dark', 'easy-expand') => 'dark',
												__('None', 'easy-expand') => 'none'
											);
											foreach( $st_array as $key => $value){
												$selected = '';
												if($options['style'] == $value){
													$selected = 'SELECTED';
												}
												echo '<option value="'.esc_attr($value).'" '.esc_attr($selected).'>'.esc_attr($key).'</option>';
											}
										?>
										</select>
										<br /><span class="description"><?php esc_attr_e('Select Light for sites with lighter backgrounds. Select Dark for sites with darker backgrounds. Select None to handle styling yourself.', 'easy-expand'); ?></span></label>
									</td>
								</tr>

								<tr>
									<th><?php esc_attr_e( 'Tag Attribute', 'easy-expand' ) ?>:</th>
									<td><label><input type="text" id="tag" name="<?php echo esc_attr($this->settings_name); ?>[tag]" value="<?php echo esc_attr($options['tag']); ?>" />
										<br /><span class="description"><?php printf(esc_attr_e('The default HTML tag attribute used to enclose the trigger text.', 'easy-expand')); ?></span></label>
									</td>
								</tr>

								<tr>
									<th><?php esc_attr_e( 'Trigclass Attribute', 'easy-expand' ) ?>:</th>
									<td><label><input type="text" id="trigclass" name="<?php echo esc_attr($this->settings_name); ?>[trigclass]" value="<?php echo esc_attr($options['trigclass']); ?>" />
										<br /><span class="description"><?php printf(esc_attr_e('The default class is applied to the trigger element. If a custom class is specified, it will be added to the trigger alongside the required *easyexpand* class, which is assigned by default.', 'easy-expand')); ?></span></label>
									</td>
								</tr>

								<tr>
									<th><?php esc_attr_e( 'Tabindex Attribute', 'easy-expand' ) ?>:</th>
									<td><label><input type="text" id="tabindex" name="<?php echo esc_attr($this->settings_name); ?>[tabindex]" value="<?php echo esc_attr($options['tabindex']); ?>" />
										<br /><span class="description"><?php printf(esc_attr_e('The default \'tabindex value\' assigned to the trigger element. Setting a numerical value for the \'tabindex\' attribute will apply that value to the trigger element. By default, \'tabindex="0"\' is used, ensuring the trigger element is included in the standard tab navigation order.', 'easy-expand')); ?></span></label>
									</td>
								</tr>

								<tr>
									<th><?php esc_attr_e( 'Targtag Attribute', 'easy-expand' ) ?>:</th>
									<td><label><input type="text" id="targtag" name="<?php echo esc_attr($this->settings_name); ?>[targtag]" value="<?php echo esc_attr($options['targtag']); ?>" />
										<br /><span class="description"><?php printf(esc_attr_e('The default HTML tag applied to the target element. This default tag, set in the plugin options, can be overridden by specifying the \'targtag\' attribute in the shortcode.', 'easy-expand')); ?></span></label>
									</td>
								</tr>

								<tr>
									<th><?php esc_attr_e( 'Targclass Attribute', 'easy-expand' ) ?>:</th>
									<td><label><input type="text" id="targclass" name="<?php echo esc_attr($this->settings_name); ?>[targclass]" value="<?php echo esc_attr($options['targclass']); ?>" />
										<br /><span class="description"><?php printf(esc_attr_e('The default class applied to the target element. If a custom class is specified, it will be added to the target element alongside the required \'easyexpand_content\' class, which is assigned by default.', 'easy-expand')); ?></span></label>
									</td>
								</tr>

								<tr>
									<th><?php esc_attr_e( 'No Title', 'easy-expand' ) ?>:</th>
									<td><label><input type="checkbox" id="notitle" name="<?php echo esc_attr($this->settings_name); ?>[notitle]" value="1"  <?php echo checked( $options['notitle'], 1 ); ?> /> <?php esc_attr_e('No Title', 'easy-expand'); ?>
										<br /><span class="description"><?php esc_attr_e('Enabling this option will disable the display of the title attribute when the trigger is hovered over with the mouse.', 'easy-expand'); ?></span></label>
									</td>
								</tr>

								<tr>
									<th><?php esc_attr_e( 'Add touchstart', 'easy-expand' ) ?>:</th>
									<td><label><input type="checkbox" id="touch_start" name="<?php echo esc_attr($this->settings_name); ?>[touch_start]" value="1"  <?php echo checked( $options['touch_start'], 1 ); ?> /> <?php esc_attr_e('Add touchstart', 'easy-expand'); ?>
										<br /><span class="description"><?php esc_attr_e('Enable the \'touchstart\' binding on triggers to address issues on touch screen devices. **Note:** This is generally not recommended and should only be used as a last-resort override if the \'click\' event fails to trigger on touch devices. If adding \'touchstart\' resolves the issue, it is likely caused by a non-standard script implemented by another plugin or the theme.', 'easy-expand'); ?></span></label>
									</td>
								</tr>

								<tr>
									<th><?php esc_attr_e( 'Initial Pause', 'easy-expand' ) ?>:</th>
									<td><label><input type="number" id="pauseinit" name="<?php echo esc_attr($this->settings_name); ?>[pauseinit]" value="<?php echo esc_attr($options['pauseinit']); ?>" />
										<br /><span class="description"><?php esc_attr_e('The time delay, in milliseconds, before triggering the initial collapse on page load. The default value is blank (zero), meaning no pause.', 'easy-expand'); ?></span></label>
									</td>
								</tr>

								<tr>
									<?php
										if(empty($options['duration'])){
												$options['duration'] = 'fast';
										}
									?>
									<th><?php esc_attr_e( 'Animation Duration', 'easy-expand' ) ?>:</th>
									<td><label><input type="text" id="duration" name="<?php echo esc_attr($this->settings_name); ?>[duration]" value="<?php echo esc_attr($options['duration']); ?>" />
										<br /><span class="description"><?php printf(esc_attr_e('Specifies the duration of the collapse and expand animation as either a string or a number. Numeric values represent the duration in milliseconds, with higher values producing slower animations. The default duration is 400 milliseconds. Alternatively, you can use the strings \'fast\' (200 milliseconds) or \'slow\' (600 milliseconds). For more information, refer to the \'.animate()\' jQuery API.', 'easy-expand')); ?></span></label>
									</td>
								</tr>

								<tr>
									<th><?php esc_attr_e( 'Animation Effect', 'easy-expand' ) ?>:</th>
									<td><label><select id="slideEffect" name="<?php echo esc_attr($this->settings_name); ?>[slideEffect]">
										<?php
											if(empty($options['slideEffect'])){
												$options['slideEffect'] = 'slideFade';
											}
											$se_array = array(
												__('Slide Only', 'easy-expand') => 'slideToggle',
												__('Slide & Fade', 'easy-expand') => 'slideFade',
												__('Fade Only', 'easy-expand') => 'fadeOnly'
											);
											foreach( $se_array as $key => $value){
												$selected = '';
												if($options['slideEffect'] == $value){
													$selected = 'SELECTED';
												}
												echo '<option value="'.esc_attr($value).'" '.esc_attr($selected).'>'.esc_attr($key).'</option>';
											}
										?>
										</select>
										<br /><span class="description"><?php printf(esc_attr_e('The animation effect used for collapsing and expanding elements: - **Slide & Fade:** Simultaneously slides the content open/close while fading it in/out, utilizing jQuery \'.animate()\'. - **Slide Only:** Slides the content open/close without fading, using jQuery \'.slideToggle()\'.', 'easy-expand')); ?></span></label>
									</td>
								</tr>

								<tr>
									<th><?php esc_attr_e( 'Custom Style', 'easy-expand' ) ?>:</th>
									<td><label><textarea id="custom_css" name="<?php echo esc_attr($this->settings_name); ?>[custom_css]"><?php echo esc_textarea($options['custom_css']); ?></textarea>
										<br /><span class="description"><?php esc_attr_e( 'Custom CSS for maximum flexibility. Use this section to add CSS if the active child theme does not provide a quick-CSS option.', 'easy-expand' ) ?></span></label>
									</td>
								</tr>

								<tr>
									<th><?php esc_attr_e( 'Content Filter', 'easy-expand' ) ?>:</th>
									<td><label><input type="checkbox" id="filter_content" name="<?php echo esc_attr($this->settings_name); ?>[filter_content]" value="1"  <?php echo checked( $options['filter_content'], 1 ); ?> /> <?php esc_attr_e('Apply filter', 'easy-expand'); ?>
										<br /><span class="description"><?php esc_attr_e('Enable this option to force WordPress’ \'the_content\' filter to be applied to content within the hidden target element. This option is disabled by default, as it is typically unnecessary. Its main purpose is to assist in troubleshooting rendering issues caused by non-standard coding practices in the active theme or other plugins.', 'easy-expand'); ?></span></label>
									</td>
								</tr>

								<tr>
									<th><?php esc_attr_e( 'Shortcode Scripts', 'easy-expand' ) ?>:</th>
									<td><label><input type="checkbox" id="script_check" name="<?php echo esc_attr($this->settings_name); ?>[script_check]" value="1"  <?php echo checked( $options['script_check'], 1 ); ?> /> <?php esc_attr_e('Only load scripts with shortcode.', 'easy-expand'); ?>
										<br /><span class="description"><?php esc_attr_e('Only load Easy Expand scripts if [expand] shortcode is used.', 'easy-expand'); ?></span></label>
									</td>
								</tr>

								<tr>
									<th><?php esc_attr_e( 'Shortcode CSS', 'easy-expand' ) ?>:</th>
									<td><label><input type="checkbox" id="css_check" name="<?php echo esc_attr($this->settings_name); ?>[css_check]" value="1"  <?php echo checked( $options['css_check'], 1 ); ?> /> <?php esc_attr_e('Only load CSS with shortcode.', 'easy-expand'); ?>
										<br /><span class="description"><?php esc_attr_e('Enable this option to load the Easy-Expand CSS only when the \'[expand]\' shortcode is used. **Note:** It is not recommended to activate this option if you are using the roll-your-own method.', 'easy-expand'); ?></span></label>
									</td>
								</tr>

								<tr>
									<th><?php esc_attr_e( 'Script Load Location', 'easy-expand' ) ?>:</th>
									<td><label><select id="script_location" name="<?php echo esc_attr($this->settings_name); ?>[script_location]">
										<?php
											if(empty($options['script_location'])){
												$options['script_location'] = 'footer';
											}
											$sl_array = array(
												__('Header', 'easy-expand') => 'header',
												__('Footer', 'easy-expand') => 'footer'
											);
											foreach( $sl_array as $key => $value){
												$selected = '';
												if($options['script_location'] == $value){
													$selected = 'SELECTED';
												}
												echo '<option value="'.esc_attr($value).'" '.esc_attr($selected).'>'.esc_attr($key).'</option>';
											}
										?>
										</select>
										<br /><span class="description"><?php esc_attr_e('Where should the script be loaded, in the Header or the Footer?', 'easy-expand'); ?></span></label>
									</td>
								</tr>
								</table>
							</fieldset>

							<p class="submit">
								<input class="button-primary" type="submit" value="<?php esc_attr_e( 'Save Changes', 'easy-expand' ) ?>" />
							</p>
						</form>
					</div>
				</div>
			</div>
            
            
		</div>

		<div class="postbox-container side metabox-holder meta-box-sortables" style="width:29%;">
			<div style="margin:0 5px;">
				<div class="postbox">
					<h2 class="hndle"><?php esc_attr_e( 'Documentation', 'easy-expand' ) ?></h2>
                    <div class="inside">
					   <p><span class="dashicons dashicons-shortcode"></span> <a onclick="javascript:jQuery('#eeblk-shortcode').show();jQuery('#eeblk-advanced').hide();" href="#blk-shortcode"><?php esc_attr_e( 'Shortcode Explanations', 'easy-expand' ) ?></a></p>
					   <p><span class="dashicons dashicons-admin-generic"></span> <a onclick="javascript:jQuery('#eeblk-advanced').show();jQuery('#eeblk-shortcode').hide();" href="#blk-advanced"><?php esc_attr_e( 'Advanced CSS usage', 'easy-expand' ) ?></a></p>
				    </div>
				</div>
			</div>
			<div class="clear"></div>
            
			<div style="margin:0 5px;">
				<div class="postbox">
					<h2 class="hndle"><?php esc_attr_e( 'About Easy Expand', 'easy-expand' ) ?></h2>
					<div class="inside">
						<h4> Easy Expand Version <?php echo esc_attr($this->version); ?></h4>
						<p><?php esc_attr_e( 'Streamline your content and optimize space! Effortlessly display or hide additional information in an SEO-friendly manner. Easily wrap any type of content—including other shortcodes—into a sleek and responsive jQuery-powered expandable and collapsible element.', 'easy-expand') ?></p>
                    </div>
				</div>
			</div>
			<div class="clear"></div>
		</div>
        
        <div id="blk-shortcode" class="postbox-container metabox-holder meta-box-sortables" style="width: 100%">
                <div style="margin:0 5px;">
    				<div class="postbox" style="padding: 0 10px;">
    					<h2><span class="dashicons dashicons-shortcode"></span> <?php esc_attr_e( 'Shortcode Explanations', 'easy-expand' ) ?></h2>
                        <p><a href="javascript:jQuery('#eeblk-shortcode').toggle();">Click to see</a></p>


<style>
.eeblk-help{display: none;line-height:1.5em!important;}
</style>
<div id="eeblk-shortcode" class="eeblk-help"><section><div><h3>Title Attribute</h3><p>the title setting is helps to define the clickable text use to trigger the accordion effect. the title setting is the only required setting for an expand element.</p>
<h4>Examples</h4>
<pre><code>[pspee_exp title="Trigger Text"][/pspee_exp]</code></pre>
<p>to assign target content for the expand element, wrapping the content within the shortcode tags like so:</p>
<pre><code>[pspee_exp title="Trigger Text"]Target Content[/pspee_exp]</code></pre>
<p>placeholdersmay be used as a work-around to include shortcodes or html inside the title setting.</p>
</div></section><hr><div><span><span></span></span></div><section><div><h3>Swaptitle Attribute</h3><p>the swaptitle setting is helps to ‘swap’ or replace the title while in the expanded state.</p>
<h4>Examples</h4>
<pre><code>[pspee_exp title="On" swaptitle="Off"]Target Content[/pspee_exp]</code></pre>
<pre><code>[pspee_exp title="Open" swaptitle="Close"]Target Content[/pspee_exp]</code></pre>
<pre><code>[pspee_exp title=""Read More..." swaptitle="...Read Less"]Target Content[/pspee_exp]</code></pre>
</div></section><hr><div><span><span></span></span></div><section><div><h3>Trigpos Attribute</h3><p>use the trigpos setting change the position of the trigger above or below the target. by default trigpos value isabove.</p>
<ul>
<li>above (default) – the trigger text is placed above the collapsed content</li>
<li>below – will move the trigger text below the target content</li>
</ul>
<h4>Example</h4>
<pre><code>[pspee_exp title="Open" trigpos="below"]Target Content[/pspee_exp]</code></pre>
</div></section><hr><div><span><span></span></span></div><section><div><h3>ID Attribute</h3><p>setting the id setting will assign the expand element ahtml id settingwith the givesd value. do not use duplicate id values on elements that will exist on the same page. if no id setting is defined, the id will be automatically assigned a unique, random value.</p>
<h4>Example</h4>
<pre><code>[pspee_exp title="Pocket Calculator" id="kraftwerk"]Target Content[/pspee_exp]</code></pre>
<h5>URL Anchor</h5>
<p>when an id setting is defined, the value can be used as an url anchor to automatically expand and scroll to the target content on page load (demo).</p>
</div></section><hr><div><span><span></span></span></div><section><div><h3>Expanded Attribute</h3><p>setting the expanded setting totruewill set the by default position of the element toopen(expanded). the by default position is closed (collapsed).</p>
<h4>Example</h4>
<pre><code>[pspee_exp title="Vader" expanded="true"]Target Content[/pspee_exp]</code></pre>
</div></section><hr><div><span><span></span></span></div><section><div><h3>Tag Attribute</h3><p>the tag setting replaces the by default html tag that wraps the trigger text. the html tag is set globally in the plugin options, under tag.</p>
<h4>Example</h4>
<pre><code>[pspee_exp title="A Long Time Ago" tag="h2"]Target Content[/pspee_exp]</code></pre>
</div></section><hr><div><span><span></span></span></div><section><div><h3>Targtag Attribute</h3><p>the targtag setting replaces the by default html tag that wraps the target content. by by default the html tag isdiv.</p>
<h4>Example</h4>
<pre><code>[pspee_exp title="A Long Time Ago" targtag="strong"]Target Content[/pspee_exp]</code></pre>
</div></section><hr><div><span><span></span></span></div><section><div><h3>Alt Attribute</h3><p>thealt settingis helps to gives additional information on non-textual screen elements that is used by screen readers and robots. in modern browsers alt text no longer “pops up” on roll-over, the title setting is now used for this.</p>
<h4>Example</h4>
<pre><code>[pspee_exp title="Imperial Starfleet" alt="Empire Strikes Back"]Target Content[/pspee_exp]</code></pre>
</div></section><hr><div><span><span></span></span></div><section><div><h3>Notitle Attribute</h3><p>the notitle setting is helps to prevent any hover-over text from being displayed.</p>
<h4>Example</h4>
<pre><code>[pspee_exp title="Cloud City" notitle="true"]Target Content[/pspee_exp]</code></pre>
</div></section><hr><div><span><span></span></span></div><section><div><h3>Placeholders</h3><p>placeholders allow html and shortcodes to be used within thetitle,swaptitle,startwrap,endwrap, excerpt and swapexcerpt settings:</p>
<pre>%(% = <
%)% = >
%{% = [
%}% = ]
</pre>
<p>see thecollapse-o-matic excerpt shortcode testfor further details on how these are used.</p>
</div></section><hr><div><span><span></span></span></div><section><div><h3>Startwrap/Endwrap Attributes</h3><p>the startwrap/endwrap tags are helps to wrap a trigger in extra html.</p>
<h4>Example</h4>
<pre><code>[pspee_exp title="Hoth System" startwrap="<strong>" endwrap="</strong>"]Target Content[/pspee_exp]</code></pre>
</div></section><hr><div><span><span></span></span></div><section><div><h3>Elwraptag Attribute</h3>
<p>the elwraptag setting is helps to wrap the entire collapse element.</p>
<h4>Example</h4>
<pre><code><?=htmlentities('<ul>[pspee_exp title="Dagobah" elwraptag="li"]Target Content[/pspee_exp]</ul>');?></code></pre>
</div></section><hr><div><span><span></span></span></div><section><div><h3>Tabindex Attribute</h3><p>assigning the tabindex setting a numerical value will set the trigger element the same tabindex value. as of collapse-o-matic version 1.6.4 the by default is tabindex=”0″ and allows the trigger element’s tabindex to be placed in the by default navigation order. initial tests and more information on the tabindex setting atcollapse-o-matic tabindex test.</p>
</div></section><hr><div><span><span></span></span></div><section><div><h3>Trigclass Attribute</h3><p>the trigclass setting allows the user to assign a custom class to the trigger element. this class will be added after the required <i>.easyexpand</i> class that is assigned by by default. multiple classes can be added separated with a space.</p>
<h4>Examples</h4>
<pre><code>[pspee_exp title="A New Hope" trigclass="highlight"]Target Content[/pspee_exp]</code></pre>
<pre><code>[pspee_exp title="Jedi" trigclass="noarrow my_button"]Target Content[/pspee_exp]</code></pre>
</div></section><hr><div><span><span></span></span></div><section><div><h3>Targclass Attribute</h3><p>the targclass setting allows the user to assign a custom class to the target element. this class will be added after the required easyexpand_content class that is assigned by by default.</p>
<h4>Examples</h4>
<pre><code>[pspee_exp title="The Empire Strikes Back" targclass="highlight"]Target Content[/pspee_exp]</code></pre>
</div></section><hr><div><span><span></span></span></div><section><div><h3>Targpos Attribute</h3><p>the targpos setting is helps to change the position of the target content. currently the only accepted value is ‘inline’. for best results, targpos should be used when:</p>
<ol>
<li>an excerpt has been defined</li>
<li>the targtag has been assigned <a href="https://www.w3schools.com/html/html_blocks.asp">non-block element</a>, such as span</li>
</ol>
<h4>Example</h4>
<pre><code>[pspee_exp title="Laugh It Up, Fuzzball" excerpt="Laugh It Up, Fuzzball: The Family Guy Trilogy." targtag="span" targpos="inline"]Target Content[/pspee_exp]</code></pre>
</div></section><hr><div><span><span></span></span></div><section><div><h3>Rel Attribute</h3><p>the rel setting is helps to group related expand elements by the assigned value. expanding a member of one group will automatically collapse any expanded elements the belong to another group.</p>
<h4>Examples</h4>
<pre><code>[pspee_exp title="Star Wars" rel="fiction"]Target Content[/pspee_exp]</code></pre>
<pre><code>[pspee_exp title="Star Trek" rel="fiction"]Target Content[/pspee_exp]</code></pre>
<pre><code>[pspee_exp title="Battlestar Galactica" rel="fiction"]Target Content[/pspee_exp]</code></pre>
<pre><code>[pspee_exp title="Space Race" rel="history"]Target Content[/pspee_exp]</code></pre>
<pre><code>[pspee_exp title="Ansari X Prize" rel="history"]Target Content[/pspee_exp]</code></pre>
<p>seerel vs togglegroupfor a working demo.</p>
</div></section><hr><div><span><span></span></span></div><section><div><h3>Togglegroup Attribute</h3><p>the togglegroup setting and the related data-togglegroup html setting are helps to reference groups of expand elements without auto-collapsing other groups, as when using the group setting.</p>
<h4>Examples</h4>
<pre><code>[pspee_exp title="Star Wars" togglegroup="fiction"]Target Content[/pspee_exp]</code></pre>
<pre><code>[pspee_exp title="Star Trek" togglegroup="fiction"]Target Content[/pspee_exp]</code></pre>
<pre><code>[pspee_exp title="Battlestar Galactica" togglegroup="fiction"]Target Content[/pspee_exp]</code></pre>
<pre><code>[pspee_exp title="Space Race" togglegroup="history"]Target Content[/pspee_exp]</code></pre>
<pre><code>[pspee_exp title="Ansari X Prize" togglegroup="history"]Target Content[/pspee_exp]</code></pre>
<p>seerel vs togglegroupfor a working demo.</p>
</div></section><hr><div><span><span></span></span></div><section><div><h3>Highlander Grouping</h3><p>if-highlanderis added to all elements of a defined group (seerelandtogglegroup), expanding one element will force all other elements in the same group to collapse:highlander:there can be only one.</p>
<h4>Examples</h4>
<p>the following is an example ofrelhighlander grouping:</p>
<pre><code>[pspee_exp title="Monkeys" rel="animal-highlander"]Target Content[/pspee_exp]</code></pre>
<pre><code>[pspee_exp title="Donkeys" rel="animal-highlander"]Target Content[/pspee_exp]</code></pre>
<p>highlander grouping can also be used with thetogglegroups:</p>
<pre><code>[pspee_exp title="Monkeys" togglegroup="animal-highlander"]Target Content[/pspee_exp]</code></pre>
<pre><code>[pspee_exp title="Donkeys" togglegroup="animal-highlander"]Target Content[/pspee_exp]</code></pre>
<p>seerel vs togglegroupfor a working demo.</p>
</div></section><hr><div><span><span></span></span></div><section><div><h3>Findme Attribute</h3>
<p>scroll the page to the trigger, target, or fixed value when expanded. accepted values are:</p>
<ul><li>auto (same as target)</li><li>target</li><li>trigger</li><li>a numeric value</li></ul>
<h4>Examples</h4>
<pre><code>[pspee_exp title="Stars" rel="star-highlander" findme="7070"]Target Content[/pspee_exp]</code></pre>
<pre><code>[pspee_exp title="Constellations" rel="star-highlander" findme="auto"]Target Content[/pspee_exp]</code></pre>
<h4>Roll-Your-Own Example</h4>
<p>usedata-findmeto define the findme value when using the roll-your-own method to create the collapse elements.</p>
<pre><code><?=htmlentities('<div class="collapseomatic find-me" id="my_example" title="trigger text" data-findme="target">trigger text</div>
<div id="target-my_example" class="collapseomatic_content">Target Content</div>');?></code></pre>
</div></section><hr><div><span><span></span></span></div><section><div><h3>Internal Collapse Trigger</h3><p>a second trigger element can be placed anywhere within the expanded content that will trigger a collapse. to accomplish this:</p>
<ol>
<li>The expand tag must have a defined ID</li>
<li>The second <em>internal</em> trigger element must be assigned a class of <strong>easyexpand</strong></li>
<li>To have the arrow point up, rather than down, add the class of <strong>pspee-close</strong> to the second trigger element</li>
<li>The bottom trigger element must have an ID that is the same as the trigger pre-appended with “bot-“. For example: if the trigger has an ID of “r2d2″ then the second trigger id must be: ”bot-r2d2”.</li>
</ol>
<h4>Example</h4>
<pre><code>[pspee_exp title="R2 may have been stolen" id="stolenr2"]
Target Content
<span><span class="easyexpand pspee-close" id="bot-stolenr2">click here to close</span>
</span>[/pspee_exp]</code></pre>
</div></section><hr><div><span><span></span></span></div><section><div><h3>Scrollonclose Attribute</h3><p>whilefindmeis triggered when the element is expanded, scrollonclose triggers when the element is collapsed. the scrollonclose setting may be assigned an exact offset-scroll value to scroll the page after the element collapses.</p>
<h4>Examples</h4>
<pre><code>[pspee_exp title="Close-n-Scroll Auto" scrollonclose="auto"]Closing this should auto scroll the page so the element is displayed at the top of the page.[/pspee_exp]</code></pre>
<pre><code>[pspee_exp title="Close-n-Scroll" scrollonclose="7000"]Closing this will auto scroll the element to 7000 pixels from the top.[/pspee_exp]</code></pre>
</div></section><hr><div><span><span></span></span></div><section><div><h3>Excerpt Attribute</h3><p>the excerpt setting is helps to display a teaser, or short nibble of text that hints at the content of the collapsed target text.</p>
<h4>Examples</h4>
<pre><code>[pspee_exp title="Laugh It Up, Fuzzball" excerpt="Laugh It Up, Fuzzball: The Family Guy Trilogy"]Target Content[/pspee_exp]</code></pre>
</div></section><hr><div><span><span></span></span></div><section><div><h3>Excerptpos Attribute</h3><p>the excerptpos setting is helps to position the excerpt in one of three locations:</p>
<ul>
<li>above-trigger</li>
<li>below-trigger (default)</li>
<li>below-target</li>
</ul>
<h4>Examples</h4>
<pre><code>[pspee_exp title="Harvest Moon" excerpt="The Family Guy - Blue Harvest" excerptpos="above-trigger"]Target Content[/pspee_exp]</code></pre>
</div></section><hr><div><span><span></span></span></div><section><div><h3>Excerptclass Attribute</h3><p>the excerptclass setting adds the defined class to the html element that wraps the excerpt text. this class will be added in addition to the by default easyexpand_excerpt class.</p>
<h4>Examples</h4>
<pre><code>[pspee_exp title="Something, Something, Something, Dark Side" excerpt="The Family Guy parody of The Empire Strikes Back" excerptclass="highlight"]Target Content[/pspee_exp]</code></pre>
</div></section><hr><div><span><span></span></span></div><section><div><h3>Excerpttag Attribute</h3><p>the excerpttag setting replaces the by default html tag that wraps the excerpt text. by default excerpt html tag isdiv.</p>
<h4>Examples</h4>
<pre><code>[pspee_exp title="It's a Trap!" excerpt="The Family Guy parody of Return of the Jedi" excerpttag="h2"]Target Content[/pspee_exp]</code></pre>
</div></section><hr><div><span><span></span></span></div><section><div><h3>Swapexcerpt Attribute</h3><p>the swapexcerpt setting is helps toswap outor replace the excerpt when the content is in the expanded state.</p>
<h4>Example</h4>
<pre><code>[pspee_exp title="Millennium Falcon" excerpt="Owner: Hans Solo" swapexcerpt="Previous Owner: Lando Calrissian"]Target Content[/pspee_exp]</code></pre>
</div></section><hr><div><span><span></span></span></div><section><div><h3>Animation_Effect Attribute</h3><p>the animation_effect setting is helps to control the collapse/expand animation effect.valid values for this setting are:</p>
<ul>
<li>slideToggle</li>
<li>slideFade</li>
<li>fadeOnly</li>
</ul>
<h4>Example</h4>
<pre><code>[pspee_exp title="trigger text" animation_effect="slideFade"]content[/pspee_exp]</code></pre>
<h4>Roll-Your-Own</h4>
<p>the data-animation_effect setting is used when rolling your own expand elements:</p>
<pre><code><?=htmlentities('<div class="easyexpand" id="some_id" title="trigger text" data-animation_effect="slideFade">content</div>');?></code></pre>
</div></section><hr><div><span><span></span></span></div><section><div><h3>Duration Attribute</h3><p>the duration setting is helps to control the speed of the collapse/expand animation in milliseconds.</p>
<h4>Example</h4>
<pre><code>[pspee_exp title="trigger text" duration="2000"]content[/pspee_exp]</code></pre>
<h4>Roll-Your-Own</h4>
<p>the data-duration setting is used when rolling your own expand elements:</p>
<pre><code><?=htmlentities('<div class="easyexpand" id="some_id" title="trigger text" data-duraton="2000">content</div>');?></code></pre>
</div></section>
</div>




    				</div>
                </div>
            </div>
            





        <div id="blk-advanced" class="postbox-container metabox-holder meta-box-sortables" style="width: 100%">
                <div style="margin:0 5px;">
    				<div class="postbox" style="padding: 0 10px;">
    					<h2><span class="dashicons dashicons-admin-generic"></span> <?php esc_attr_e( 'Advanced CSS usage', 'easy-expand' ) ?></h2>
                        <p><a href="javascript:jQuery('#eeblk-advanced').toggle();">Click to see</a></p>


<div id="eeblk-advanced" class="eeblk-help"><section><div><h3>Arrows</h3><p>Two sets of up/down arrow images are added with the plugin. Also added is a Photoshop .psd file that lets you as a template to create custom arrows. To keep changes safe from updates to the arrows, place the new arrow images in the same folder as the child-theme style.css file. Then, add the following to the style.css file or the theme quick-css section:</p>
<h4>CSS:</h4>
<pre><code>.easyexpand {
    background-image: url(your_down_arrow_image_here.png) !important;
}
.pspee-close {
    background-image: url(iour_up_arrow_image_here.png) !important;
}</code></pre>
<p>The arrow position can be set to display right of the trigger assigning the trigclass attribute a value ofarrowright. The arrow can be completely removed by assigning the the trigclass a value ofnoarrow.</p>
<p>For step-by-step instructions on how to integrate custom arrows, see theCollapse-O/Pro-Matic CSS Tricks – ArrowsandCollapse-O/Pro-Matic CSS Tricks II – Font Awesome Arrowsarticles.</p>
</div></section><hr><div><span><span></span></span></div><section><div><h3>Visited</h3><p>Expand elements that have been clicked and expanded at least once will have the <i>.pspee-visited</i> class added by default. To modify the appearance of visited expand elements, the <i>.pspee-visited</i> class need only be defined.</p>
<h4>CSS:</h4>
<pre><code>.pspee-visited {
    color: #0073aa;
}</code></pre>
</div></section><hr><div><span><span></span></span></div><section><div><h3>Nested Expand Elements</h3><p>Expand elements can be nested up to 30 levels deep by using special codes:[pspee_expsub1]–[pspee_expsub30]</p>
<h4>Example</h4>
<pre><code>[pspee_exp title="Root Level"]
   [pspee_expsub1 title="Nested Level 1"]
      [pspee_expsub2 title="Nested Level 2"]
         [pspee_expsub3 title="Nested Level 3"]
           [pspee_expsub4 title="Nested Level 4"]
             [pspee_expsub5 title="Nested Level 5"]
               [pspee_expsub6 title="Nested Level 6"]
                 [pspee_expsub7 title="Nested Level 7"]
                 [/pspee_expsub7]
               [/pspee_expsub6]
             [/pspee_expsub5]
           [/pspee_expsub4]
         [/pspee_expsub3]
      [/pspee_expsub2]
   [/pspee_expsub1]
[/pspee_exp]</code></pre>
</div></section><hr><div><span><span></span></span></div><section><div><h3>Grouping Nested Elements</h3><p>Using nested expand elements with grouping can be complex. Below is an examples of how nested elements might be used in a navigation menu. Notice how the first menu item uses highlander grouping for the nested elements, while the second menu item does not.</p>
<h4>Example</h4>
<pre><code>[pspee_exp title="Fiction" rel="fiction"]
  [pspee_expsub2 title="Star Wars" rel="submenu-highlander"]Target Content[/pspee_expsub2]
  [pspee_expsub2 title="Star Trek" rel="submenu-highlander"]Target Content[/pspee_expsub2]
  [pspee_expsub2 title="Battlestar Galactica" rel="submenu-highlander"]Target Content[/pspee_expsub2]
[/pspee_exp]
[pspee_exp title="History" rel="history"]
  [pspee_expsub2 title="Space Race"]
    [pspee_expsub3 title="Moon Landing"]Target Content[/pspee_expsub3]
  [/pspee_expsub2]
  [pspee_expsub2 title="Ansari X Prize"]Target Content[/pspee_expsub2]
[/pspee_exp]</code></pre>
<p>Since the nested elements of the first group:Fictionis using highlander grouping, only a single nested element is allowed to be open at a time. The second group:Historydoes not use highlander grouping, allowing multiple elements on the same level to be open simultaneously.</p>
</div></section><hr><div><span><span></span></span></div><section><div><h3>Nested Highlander Elements</h3><p>Here is an example of deeply nested elements using highlander grouping.</p>
<h4>Example</h4>
<pre><code>[pspee_exp title="Fiction" rel="fiction"]
  [pspee_expsub2 title="Star Wars" rel="submenu-highlander"]
    [pspee_expsub3 title="Rebels" rel="subsubmenu-highlander"]
      [pspee_expsub4 title="Skywalker" rel="sub3menu-highlander"]
        [pspee_expsub5 title="Luke" rel="sub4menu-highlander"]
          [pspee_expsub6 title="Droids" rel="sub5menu-highlander"]
            [pspee_expsub7 title="R2D2" rel="sub6menu-highlander"]Beep Boo Bop Beep[/pspee_expsub7]
            [pspee_expsub7 title="C3PO" rel="sub6menu-highlander"]Master Luke![/pspee_expsub7]
          [/pspee_expsub6]
          [pspee_expsub6 title="Light Saber" rel="sub5menu-highlander"]WaaaaWaaaooe Wap-Waaaaa[/pspee_expsub6]
        [/pspee_expsub5]
        [pspee_expsub5 title="Leah" rel="sub4menu-highlander"]I am going Solo![/pspee_expsub5]
      [/pspee_expsub4]
      [pspee_expsub4 title="Knobi" rel="sub3menu-highlander"]Obi Wan Knobi[/pspee_expsub4]
    [/pspee_expsub3]
    [pspee_expsub3 title="Empire" rel="subsubmenu-highlander"]The Dark Side of the Force[/pspee_expsub3]
  [/pspee_expsub2]
  [pspee_expsub2 title="Star Trek" rel="submenu-highlander"]Target Content[/pspee_expsub2]
  [pspee_expsub2 title="Battlestar Galactica" rel="submenu-highlander"]Target Content[/pspee_expsub2]
[/pspee_exp]</code></pre>
</div></section><hr><div><span><span></span></span></div><section><div><h3>Expand/Collapse All Triggers</h3>
<p>Create unique external triggers that will Expand or collapse all elements on the page. The triggers can be made from any HTML element as long as it has been assigned a class of either <em>expandall</em> or <em>collapseall</em>.</p>
<h4>Examples</h4>
<pre><code><?=htmlentities('<span class="expandall">Expand All</span>
<span class="collapseall">Collapse All</span>')?></code></pre>
</div></section><hr><div><span><span></span></span></div><section><div><h3>Expand/Collapse All Grouped</h3>
<p>Expand and collapse all elements belonging to the same group with one trigger. The triggers may be any type of HTML tag as long as they have a class of eitherexpandallorcollapseallandthe same rel attribute of the target group.</p>
<h4>Examples</h4>
<pre><code><?=htmlentities('<span class="expandall" rel="fiction">Expand All</span>
<span class="collapseall" rel="fiction">Collapse All</span>')?></code></pre>
</div></section><hr><div><span><span></span></span></div><section><div><h3>Setall Toggle</h3>
<p>Expand and collapse all elements, or only those belonging to the same group with a single toggle trigger. The toggle is created using the expand shortcode with a trigclass of setall. Assigning a swaptitle is also recommended to clarify the toggle.</p>
<h4>Examples</h4>
<pre><code>[pspee_exp title="Expand All" swaptitle="Collapse All" trigclass="setall"/]</code></pre>
<p>To expand/collapse only members of a specific group, a group name must be provided using the rel attribute:</p>
<pre><code>[pspee_exp title="Expand All" swaptitle="Collapse All" trigclass="setall" rel="my_group"/]
[pspee_exp title="expand 1" rel="my_group"]this is the first expand item[/pspee_exp]
[pspee_exp title="expand 2" rel="my_group"]this is the second expand item[/pspee_exp]</code></pre>
</div></section><hr><div><span><span></span></span></div><section><div><h3>Internal Collapse Trigger</h3>
<p>A second trigger element can be placed anywhere within the expanded content that will trigger a collapse. To accomplish this:</p>
<ol><li>The expand tag must have a defined ID</li><li>The second <em>internal</em> trigger element must be assigned a class of <em>easyexpand</em></li><li>To have the arrow point up, rather than down, add the class of <em>pspee-close</em> to the second trigger element</li><li>The bottom trigger element must have and ID that is the same as the trigger pre-appended with <code>bot-</code>. For example: if the trigger has an ID of  <em>r2d2</em> then the second trigger id must look like: <code>id="bot-r2d2"</code>.</li></ol>
<h4>Examples</h4>
<pre><code>[pspee_exp title="R2 may have been stolen" id="r2d2"]Target Content
<span class="easyexpand pspee-close" id="bot-r2d2">click here to close</span>
[/pspee_exp]</code></pre>
<h5>Scroll On Close</h5>
<p>Often an internal collapse trigger is used because there is a large amount of content. Therefore, it may also be useful to have the page automatically scroll to the main trigger text when the bottom trigger is clicked. To do this, simply add thescroll-to-triggerclass to the bottom trigger element.</p>
<pre><code>[pspee_exp title="R2D2 Wiki" id="r2d2wiki"]Target Content
<span class="easyexpand pspee-close scroll-to-trigger" id="bot-r2d2wiki">click here to close & scroll to trigger</span>
[/pspee_exp]</code></pre>
</div></section><hr><div><span><span></span></span></div><section><div><h3>The Roll Your Own Method</h3>
<p>With the plugin installed, any two elements can be rolled into a triger/target collapse-o-matic pair. To roll-your-own collapse elements, simply keep the following in mind:</p>
<ol><li>The <em>trigger</em> element has to be wrapped in an element with the class of  <em>easyexpand</em> and a unique id</li><li>The <em>target</em> element has to be wrapped in an element with the class of <em>easyexpand-content</em></li><li>The <em>target</em> element also has ID requirements. It must be the same as the trigger pre-appended with <em>target-</em>. For example: if the trigger has an ID of <em>kraftwerk</em> then the matching target ID must look like: <code>id="target-kraftwerk"</code></li></ol>
<p>More information, complete with working demonstrations, can be found in the post:Collapse-O-Matic – The Roll Your Own Method</p>
<h4>Examples</h4>
<p>A roll-your-own example that places the trigger (with a swaptitle)belowthe target:</p>
<pre><code><?=htmlentities('<div id="target-monkey1" class="easyexpand_content">Target Content</div>
<span class="easyexpand" title="Fast Monkey" id="monkey1" >Fast Monkey</span>
<span id="swap-monkey1" style="display: none;">Eek Eek</span>');?></code></pre>
<p>A roll-your-own example that uses the findme feature:</p>
<pre><code><?=htmlentities('<span id="find-donkey"></span>
<span class="easyexpand find-me" title="Slow Donkey" id="donkey">Slow Donkey</span>
<div id="target-donkey" class="easyexpand_content">Donkeys are not so fast.</div>');?></code></pre>
<p>For more examples of rolling your own collapse elements, check out Terryago’s excellent post on the WordPress Forums:Roll your own Elements Ideas.</p>
</div></section><hr><div><span><span></span></span></div><section><div><h3>Multiple Triggers</h3>
<p>Multiple triggers lets you for the same target. This works only for roll-your-own collapse elements. The extra triggers elements must contain the following:</p>
<ul><li>Have a defined id in the format of ‘extra[<em>n</em>]-<em>orginal_id</em>‘</li><li>Contain a class of ‘easyexpand’</li></ul>
<h4>Example</h4>
<pre><code><?=htmlentities('<div id="test" class="easyexpand">Trigger 1</div>
<div id="target-test" class="easyexpand_content">Target Content</div>
<div id="extra1-test" class="easyexpand">Trigger 2</div>
<div id="extra2-test" class="easyexpand">Trigger 3</div>');?></code></pre>
</div></section><div><span><span></span></span></div><section><div><h3>Special Classes</h3><p></p><section><div><p>There are a number of special classes that can be assigned in shortcodes using either the trigclass or targclass attributes. These classes can also be assigned to trigges, targets and external HTML elements using the roll-your-own method. An overview of these special class are listed in the table below.</p>
</div></section><p></p>
<p></p><div>
  <table style="width:100%">
    <tbody>
        <tr style="text-align: left;">
            <th>Class Name</th>
            <th>Used By</th>
            <th>Purpose</th>
        </tr>
        <tr>
            <td>arrowright</td>
            <td>trigclass</td>
            <td>places expand/collapse arrows to the right of trigger text</td>
        </tr>
        <tr>
            <td>noarrow</td>
            <td>trigclass</td>
            <td>removes the expand/collapse arrows</td>
        </tr>
        <tr>
            <td>pspee-expand-only</td>
            <td>trigclass</td>
            <td>expand elements can be expanded only once and then will remain locked open</td>
        </tr>
        <tr>
            <td>maptastic</td>
            <td>targclass</td>
            <td>The target content area will not be hidden initially but rather placed off screen to allow other shortcodes such as google maps to render.</td>
        </tr>
        <tr>
            <td>pspee-nolink</td>
            <td>trigclass</td>
            <td>Anchor ‘a’ tags used as triggers will not fire links if they have been assigned this class.</td>
        </tr>
        <tr>
            <td>must-be-one</td>
            <td>targclass</td>
            <td>add this class to the trigger of all elements in a highlander-group and the open element will be forced to stay open.</td>
        </tr>
        <tr>
            <td>scroll-to-trigger</td>
            <td>internal trigger</td>
            <td>If this class is assigned to an internal collapse trigger, the page will automatically scroll to the expand trigger when clicked.</td>
        </tr>
        <tr>
            <td>pspee-visited</td>
            <td>trigger</td>
            <td>This class is automatically applied to any expand element that has been clicked at least once.</td>
        </tr>
        <tr>
            <td>expandanchor</td>
            <td>link</td>
            <td>Assign this class to an anchor link to auto-expand a collapse element on the same page.</td>
        </tr>
        <tr>
            <td>snap-shut</td>
            <td>trigclass</td>
            <td>Assign this class to a trigger to immediately close it rather than smoothly animate the collapse. Useful when used with highlander grouping.</td>
        </tr>
        <tr>
            <td>expandall</td>
            <td>any HTML element</td>
            <td>Expand all elements with one external trigger. The trigger may be any type of HTML tag.</td>
        </tr>
        <tr>
            <td>collapseall</td>
            <td>any HTML element</td>
            <td>Collapse all elements with one external trigger. The trigger may be any type of HTML tag.</td>
        </tr>
        <tr>
            <td>must-be-one</td>
            <td>trigclass</td>
            <td>Forces one element to stay open in a highlander grouping.</td>
        </tr>
    </tbody>
</table>
</div><style type="text/css">.avia-table-1 td:nth-of-type(1):before { content: 'Class Name'; } .avia-table-1 td:nth-of-type(2):before { content: 'Used By'; } .avia-table-1 td:nth-of-type(3):before { content: 'Purpose '; } </style><p></p>
</div></section>
</div>

 
            
            
    				</div>
                </div>
            </div>


	<?php
	}

	/**
	 * Set settings from save values or defaults
	 */
	function _set_settings() {
		// set settings
		$saved_settings = get_option( $this->settings_name );

		// backwards compatible (old values)
		if ( empty( $saved_settings ) ) {
            $saved_settings = get_option( $this->domain . 'settings' );
		}
		// set all options
		if ( !empty( $saved_settings ) ) {
			foreach ( $this->settings AS $key => $option ) {
				if($key == 'tabindex'){
					$this->settings[ $key ] = in_array( $key, $saved_settings ) ? $saved_settings[ $key ] : 0;
				}
				else{
					$this->settings[ $key ] = ( empty( $saved_settings[ $key ] ) ) ? '' : $saved_settings[ $key ];
				}
			}
		}
	}


	

	/**
	 * Filter $input to allow only tags from $allowed_tags array
	 */
	function filter_allowed_tags( $input, $allowed_tags ) {
		$pattern = '/\A(' . implode( '|', $allowed_tags ) . ')\Z/';
		if ( preg_match( $pattern, $input, $matches ) ) {
			$output = $matches[0];
		} else {
			$output = '';
		}

		return $output;
	}

} // end class PSPEE_Easy_Expand


/**
 * Create instance
 */
$PSPEE_Easy_Expand = new PSPEE_Easy_Expand;


function pspee_sanitize_text_or_array_field($array_or_string) {
    if( is_string($array_or_string) ){
        $array_or_string = sanitize_text_field($array_or_string);
    }elseif( is_array($array_or_string) ){
        foreach ( $array_or_string as $key => &$value ) {
            if ( is_array( $value ) ) {
                $value = pspee_sanitize_text_or_array_field($value);
            }
            else {
                $value = sanitize_text_field( $value );
            }
        }
    }

    return $array_or_string;
}

if (!function_exists('pspee_clean_shortcodes')) {
	function pspee_clean_shortcodes($content){
		$array = array (
		    '<p>[' => '[',
		    ']</p>' => ']',
		    ']<br />' => ']'
		);
		$content = strtr($content, $array);
		return $content;
	}
	add_filter('the_content', 'pspee_clean_shortcodes');
}

?>